summaryrefslogtreecommitdiffstats
path: root/usr.sbin/ppp/radius.c
diff options
context:
space:
mode:
authorbrian <brian@FreeBSD.org>2000-03-14 01:46:09 +0000
committerbrian <brian@FreeBSD.org>2000-03-14 01:46:09 +0000
commit9c5b52bb1ff54c68085f3d991416208f25de7639 (patch)
treedbe961365e18f19df00ee52df51b62d05741ec40 /usr.sbin/ppp/radius.c
parentfe41605fe0c0e256c26622b4c8e5edf23f72d7c7 (diff)
downloadFreeBSD-src-9c5b52bb1ff54c68085f3d991416208f25de7639.zip
FreeBSD-src-9c5b52bb1ff54c68085f3d991416208f25de7639.tar.gz
To avoid namespace polution in NetBSD:
``struct descriptor'' -> ``struct fdescriptor''
Diffstat (limited to 'usr.sbin/ppp/radius.c')
-rw-r--r--usr.sbin/ppp/radius.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/usr.sbin/ppp/radius.c b/usr.sbin/ppp/radius.c
index e46baee..cdd30f5 100644
--- a/usr.sbin/ppp/radius.c
+++ b/usr.sbin/ppp/radius.c
@@ -225,7 +225,7 @@ radius_Process(struct radius *r, int got)
}
/*
* We've either timed out or select()ed on the read descriptor
*/
static void
radius_Continue(struct radius *r, int sel)
@@ -257,16 +257,16 @@ radius_Timeout(void *v)
* Time to call rad_continue_send_request() - something to read.
*/
static void
-radius_Read(struct descriptor *d, struct bundle *bundle, const fd_set *fdset)
+radius_Read(struct fdescriptor *d, struct bundle *bundle, const fd_set *fdset)
{
radius_Continue(descriptor2radius(d), 1);
}
/*
* Behave as a struct descriptor (descriptor.h)
*/
static int
-radius_UpdateSet(struct descriptor *d, fd_set *r, fd_set *w, fd_set *e, int *n)
+radius_UpdateSet(struct fdescriptor *d, fd_set *r, fd_set *w, fd_set *e, int *n)
{
struct radius *rad = descriptor2radius(d);
@@ -282,10 +282,10 @@ radius_UpdateSet(struct descriptor *d, fd_set *r, fd_set *w, fd_set *e, int *n)
}
/*
* Behave as a struct descriptor (descriptor.h)
*/
static int
-radius_IsSet(struct descriptor *d, const fd_set *fdset)
+radius_IsSet(struct fdescriptor *d, const fd_set *fdset)
{
struct radius *r = descriptor2radius(d);
@@ -293,10 +293,10 @@ radius_IsSet(struct descriptor *d, const fd_set *fdset)
}
/*
* Behave as a struct descriptor (descriptor.h)
*/
static int
-radius_Write(struct descriptor *d, struct bundle *bundle, const fd_set *fdset)
+radius_Write(struct fdescriptor *d, struct bundle *bundle, const fd_set *fdset)
{
/* We never want to write here ! */
log_Printf(LogALERT, "radius_Write: Internal error: Bad call !\n");
@@ -225,7 +225,7 @@ radius_Process(struct radius *r, int got)
}
/*
- * We've either timed out or select()ed on the read descriptor
+ * We've either timed out or select()ed on the read fdescriptor
*/
static void
@@ -257,16 +257,16 @@ radius_Timeout(void *v)
}
/*
- * Behave as a struct descriptor (descriptor.h)
+ * Behave as a struct fdescriptor (fdescriptor.h)
*/
static int
@@ -282,10 +282,10 @@ radius_UpdateSet(struct descriptor *d, fd_set *r, fd_set *w, fd_set *e, int *n)
}
/*
- * Behave as a struct descriptor (descriptor.h)
+ * Behave as a struct fdescriptor (fdescriptor.h)
*/
static int
@@ -293,10 +293,10 @@ radius_IsSet(struct descriptor *d, const fd_set *fdset)
}
/*
- * Behave as a struct descriptor (descriptor.h)
+ * Behave as a struct fdescriptor (fdescriptor.h)
*/
static int
OpenPOWER on IntegriCloud